==> haskell-hls-ormolu-plugin-2.0.0.0-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-ormolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-ormolu-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-ormolu-plugin-2.0.0.0-36bdom75LEgEA9oGzTxwFL
key:                  hls-ormolu-plugin-2.0.0.0-36bdom75LEgEA9oGzTxwFL
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Ormolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1f9bc5d3f8bdba518e4505295294a138
exposed:              True
exposed-modules:      Ide.Plugin.Ormolu
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-ormolu-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-ormolu-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-ormolu-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-ormolu-plugin
hs-libraries:         HShls-ormolu-plugin-2.0.0.0-36bdom75LEgEA9oGzTxwFL
depends:
    base-4.17.2.1 filepath-1.4.2.2 ghc-9.4.8 ghc-boot-th-9.4.8
    ghcide-2.0.0.0-2OoOssIvpRZJ70cxoplPUd
    hls-plugin-api-2.0.0.0-CjPH3i9n95sAzh7VU9zzvQ
    lens-5.2.3-DnVNcFpsuwMCXFWImXsY2L
    lsp-1.6.0.0-EzZWHSTgh2eBqXWsr3rUZN
    ormolu-0.5.1.0-2eZbg870SR82navpX4tMMH text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-ormolu-plugin/html/hls-ormolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-ormolu-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-ormolu-plugin-2.0.0.0-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-ormolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-ormolu-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-ormolu-plugin-2.0.0.0-72AcIAeuIMvDu8BwMIRpOy
key:                  hls-ormolu-plugin-2.0.0.0-72AcIAeuIMvDu8BwMIRpOy
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Ormolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  6ae3848193d55403b5d74e866ef56d11
exposed:              True
exposed-modules:      Ide.Plugin.Ormolu
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-ormolu-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-ormolu-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-ormolu-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-ormolu-plugin
hs-libraries:         HShls-ormolu-plugin-2.0.0.0-72AcIAeuIMvDu8BwMIRpOy
depends:
    base-4.17.2.1 filepath-1.4.2.2 ghc-9.4.8 ghc-boot-th-9.4.8
    ghcide-2.0.0.0-7O5MlhTeuzxG8Z14Vz3F5R
    hls-plugin-api-2.0.0.0-BSQontPVPIA4EciidEETjs
    lens-5.2.3-DnVNcFpsuwMCXFWImXsY2L
    lsp-1.6.0.0-1RxTvmiJB0d2TzCGfgQy8D
    ormolu-0.5.1.0-2eZbg870SR82navpX4tMMH text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-ormolu-plugin/html/hls-ormolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-ormolu-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
